%global tests 1
%global python3 python%{python3_pkgversion}

Name:    lensfun
Version: 0.3.3
Summary: Library to rectify defects introduced by photographic lenses
Release:    1%{?dist}

License: LGPLv3 and CC-BY-SA
URL: https://lensfun.github.io/
Source0: https://github.com/lensfun/lensfun/archive/v%{version}/%{name}-%{version}.tar.gz


Patch866: 0866-Pull-isnan-into-std-namespace-include-cmath-not-math.patch

Patch200: lensfun-0.3.2-INSTALL_HELPER_SCRIPTS.patch

BuildRequires: cmake
BuildRequires: doxygen
BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires: pkgconfig(glib-2.0) 
BuildRequires: pkgconfig(libpng) 
BuildRequires: pkgconfig(zlib)
%if 0%{?python3:1}
BuildRequires: %{python3} %{python3}-devel
%else
%endif
BuildRequires: /usr/bin/rst2man

%description
The lensfun library provides an open source database of photographic lenses and
their characteristics. It not only provides a way to read and search the
database, but also provides a set of algorithms for correcting images based on
detailed knowledge of lens properties. Right now lensfun is designed to correct
distortion, transversal (also known as lateral) chromatic aberrations,
vignetting and color contribution of a lens.

%package devel
Summary: Development toolkit for %{name}
License: LGPLv3
Requires: %{name} = %{version}-%{release}
%description devel
This package contains library and header files needed to build applications
using lensfun.

%package tools
Summary: Tools for managing %{name} data
License: LGPLv3
Requires: %{python3}-lensfun = %{version}-%{release}
%description tools
This package contains tools to fetch lens database updates and manage lens
adapters in lensfun.

%package -n %{python3}-lensfun
Summary:  Python3 lensfun bindings
Requires: %{name} = %{version}-%{release}
%description -n %{python3}-lensfun
%{summary}.


%prep
%setup -q


%patch -P 866 -p1 -b .0866

%patch -P 200 -p1 -b .INSTALL_HELPER_SCRIPTS

%if 0%{?python3:1}
sed -i.shbang \
  -e "s|^#!/usr/bin/env python3$|#!%{__python3}|g" \
  apps/lensfun-add-adapter \
  apps/lensfun-update-data
%endif


%build
%cmake \
  -DBUILD_DOC:BOOL=ON \
  -DBUILD_TESTS:BOOL=%{?tests:ON}%{!?tests:OFF} \
  -DCMAKE_BUILD_TYPE:STRING=Release \
  -DCMAKE_INSTALL_DOCDIR:PATH=%{_pkgdocdir} \
  %{?!python3:-DINSTALL_HELPER_SCRIPTS:BOOL=OFF}

%cmake_build

%cmake_build --target doc


%install
%cmake_install

mkdir -p %{buildroot}/var/lib/lensfun-updates

rm -fv %{buildroot}%{_bindir}/g-lensfun-update-data \
       %{buildroot}%{_mandir}/man1/g-lensfun-update-data.* \
       %{buildroot}%{_docdir}/%{name}/doxygen.svg


%check
%if 0%{?tests}
export CTEST_OUTPUT_ON_FAILURE=1
%ctest
%endif



%files
%doc README.md
%license docs/cc-by-sa-3.0.txt docs/lgpl-3.0.txt
%{_datadir}/lensfun/
%{_libdir}/liblensfun.so.%{version}
%{_libdir}/liblensfun.so.1*
%dir /var/lib/lensfun-updates/

%files devel
%{_pkgdocdir}/*.html
%{_pkgdocdir}/*.png
%{_pkgdocdir}/*.css
%{_pkgdocdir}/*.js
%{_pkgdocdir}/*.svg
%{_includedir}/lensfun/
%{_libdir}/liblensfun.so
%{_libdir}/pkgconfig/lensfun.pc

%if 0%{?python3:1}
%files tools
%{_bindir}/lensfun-add-adapter
%{_bindir}/lensfun-update-data
%{_mandir}/man1/lensfun-add-adapter.1*
%{_mandir}/man1/lensfun-update-data.1*

%files -n %{python3}-lensfun
%{python3_sitelib}/lensfun*.egg
%endif


%changelog
* Mon Jul 01 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.3.3-1
- initial build
